# py-wtf
A static analyzer of Python which forces you to write comments, and write them in a well-mannered way.

**wtf** is short for **what the function** or **why that function**.  

Since most of the time, when you read some code snippet of your own without comments, you might have the question, "what the function was used for? Why did I write that function? What the hell was I thinking about at that time?" And my product is to help you with this problem.

---

## Developing
Install `py-wtf` for development:

```bash
sudo python3 setup.py develop
```

---

## Usage
```bash
wtf testfile.py
```
